@@ -21,6 +21,7 @@ import logging
 from pysvnmanager.lib.base import *
 from pysvnmanager.model.svnauthz import *
 from pysvnmanager.model import repos as _repos
+from pylons.i18n import _, ungettext, N_
 
 log = logging.getLogger(__name__)
 
@@ -28,21 +29,30 @@ class CheckController(BaseController):
     requires_auth = True
 
     def __init__(self):
-        self.authz = SvnAuthz(cfg.authz_file)
-        self.login_as = session.get('user')
-        # Used as checked in user to rcs file.
-        self.authz.login_as = self.login_as
-        self.reposlist = self.authz.get_manageable_repos_list(self.login_as)
-        if self.authz.is_super_user(self.login_as):
-            for i in _repos.Repos(cfg.repos_root).repos_list:
-                if i not in self.reposlist:
-                    self.reposlist.append(i)
-            self.reposlist = sorted(self.reposlist)
+        c.menu_active = "check"
+        try:
+            self.authz = SvnAuthz(cfg.authz_file)
+            self.login_as = session.get('user')
+            # Used as checked in user to rcs file.
+            self.authz.login_as = self.login_as
+            self.reposlist = self.authz.get_manageable_repos_list(self.login_as)
+            if self.authz.is_super_user(self.login_as):
+                for i in _repos.Repos(cfg.repos_root).repos_list:
+                    if i not in self.reposlist:
+                        self.reposlist.append(i)
+                self.reposlist = sorted(self.reposlist)
+        except Exception, e:
+            import traceback
+            g.catch_e = [unicode(e), traceback.format_exc(5) ]
+            return
 
-    def __before__(self, action):
+    def __before__(self, action=None):
         super(CheckController, self).__before__(action)
         if not self.reposlist:
-            return redirect_to(h.url_for(controller='security', action='failed'))
+            return redirect(url(controller='security', action='failed'))
+        diff = self.authz.differ()
+        if diff:
+            c.global_message = _('Some one maybe you, has modified the svn authz file by hands. Please save once to fix possible config error.') + "<blockquote>" + "<br>".join(diff.splitlines()) + "</blockquote>"
         
     def index(self):
         c.reposlist = self.reposlist
