@@ -19,7 +19,9 @@
 import logging
 
 from pysvnmanager.lib.base import *
+from pysvnmanager.lib.text import to_unicode
 from pysvnmanager.model.svnauthz import *
+from pylons.i18n import _, ungettext, N_
 
 log = logging.getLogger(__name__)
 
@@ -27,20 +29,28 @@ class RoleController(BaseController):
     requires_auth = True
 
     def __init__(self):
-        self.authz = SvnAuthz(cfg.authz_file)
-        self.login_as = session.get('user')
-        # Used as checked in user to rcs file.
-        self.authz.login_as = self.login_as
-        self.aliaslist  = map(lambda x:x.uname, self.authz.aliaslist)
-        self.userlist = map(lambda x:x.uname, self.authz.userlist)
-        self.grouplist = map(lambda x:x.uname, self.authz.grouplist)
-        self.is_super_user = self.authz.is_super_user(self.login_as)
-        self.own_reposlist = self.authz.get_manageable_repos_list(self.login_as)
+        try:
+            self.authz = SvnAuthz(cfg.authz_file)
+            self.login_as = session.get('user')
+            # Used as checked in user to rcs file.
+            self.authz.login_as = self.login_as
+            self.aliaslist  = map(lambda x:x.uname, self.authz.aliaslist)
+            self.userlist = map(lambda x:x.uname, self.authz.userlist)
+            self.grouplist = map(lambda x:x.uname, self.authz.grouplist)
+            self.is_super_user = self.authz.is_super_user(self.login_as)
+            self.own_reposlist = self.authz.get_manageable_repos_list(self.login_as)
+        except Exception, e:
+            import traceback
+            g.catch_e = [unicode(e), traceback.format_exc(5) ]
+            return
 
-    def __before__(self, action):
+    def __before__(self, action=None):
         super(RoleController, self).__before__(action)
         if not self.own_reposlist and not self.is_super_user:
-            return redirect_to(h.url_for(controller='security', action='failed'))
+            return redirect(url(controller='security', action='failed'))
+        diff = self.authz.differ()
+        if diff:
+            c.global_message = _('Some one maybe you, has modified the svn authz file by hands. Please save once to fix possible config error.') + "<blockquote>" + "<br>".join(diff.splitlines()) + "</blockquote>"
 
     def index(self):
         c.revision = self.authz.version
@@ -128,7 +138,7 @@ class RoleController(BaseController):
             self.authz.set_group(rolename, member_list, autodrop=autodrop)
             self.authz.save(revision, comment=log_message)
         except Exception, e:
-            msg = except_to_unicode(e)
+            msg = to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
@@ -150,7 +160,7 @@ class RoleController(BaseController):
                 self.authz.del_group(rolename)
                 self.authz.save(revision, comment=log_message)
             except Exception, e:
-                msg = except_to_unicode(e)
+                msg = to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
@@ -172,7 +182,7 @@ class RoleController(BaseController):
             self.authz.add_alias(aliasname, username)
             self.authz.save(revision, comment=log_message)
         except Exception, e:
-            msg = except_to_unicode(e)
+            msg = to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
@@ -194,7 +204,7 @@ class RoleController(BaseController):
                 self.authz.del_alias(aliasname)
                 self.authz.save(revision, comment=log_message)
             except Exception, e:
-                msg = except_to_unicode(e)
+                msg = to_unicode(e)
 
         log.info(log_message)
         if msg: log.error(msg)
