@@ -38,8 +38,8 @@ class EolStyleCheck(PluginBase):
     type = T_PRE_COMMIT
     
     # Plugin config option/value in config ini file.
-    key = "eol_style_check"
-    value = "yes"
+    key_switch = "eol_style_check"
+    key_force  = "eol_style_check_force"
     
     section = 'pre_commit'
     
@@ -48,7 +48,7 @@ class EolStyleCheck(PluginBase):
         Return True, if this plugin has been installed.
         Simply call 'has_config()'.
         """
-        return self.has_config()
+        return self.has_config(self.key_switch)
     
     def install_info(self):
         """
@@ -57,7 +57,18 @@ class EolStyleCheck(PluginBase):
         return reStructuredText.
         reST reference: http://docutils.sourceforge.net/docs/user/rst/quickref.html
         """
-        return self.description
+        result = self.description
+        if self.enabled():
+            result += "\n\n"
+            result += "**" + _("Current configuration") + "**\n\n"
+            force = self.get_config(self.key_force)
+            if force == "no":
+                result += "- " + _("Loose mode: permit checkin without svn:eol-style properity if no CRLF in text file.")
+            else:
+                result += "- " + _("Strict mode: must have svn:eol-style even if not CRLF in text file.")
+
+        return result
+ 
     
     def install_config_form(self):
         """
@@ -65,14 +76,38 @@ class EolStyleCheck(PluginBase):
         If this plugin needs parameters, provides form fields here.
         Any html and javascript are welcome.
         """
-        return ""
+        if self.get_config(self.key_force)=="no":
+            enable_checked  = ""
+            disable_checked = "checked"
+        else:
+            enable_checked  = "checked"
+            disable_checked = ""
+
+        result = ""
+        result += "<p><strong>%s</strong></p>" % _("Fill this form")
+        result += "<blockquote>"
+        result += "<dl>"
+        result += "\n<dt>"
+        result += "<input type='radio' name='force' value='yes' " + \
+                enable_checked  + ">" + _("Strict mode") + "&nbsp;"
+        result += "\n<dd>"
+        result += _("Must set svn:eol-style even if CRLF not in text file (in Unix format).")
+        result += "\n<dt>"
+        result += "<input type='radio' name='force' value='no' " + \
+                disable_checked + ">" + _("Loose mode") + "<br>"
+        result += "\n<dd>"
+        result += _("Permit checkin without svn:eol-style properity if is in Unix file format (no crlf in text file).")
+        result += "\n</dl>"
+        result += "</blockquote>"
+        return result
         
     def uninstall(self):
         """
         Uninstall hooks-plugin from repository.
         Simply call 'unset_config()' and 'save()'.
         """
-        self.unset_config()
+        self.unset_config(self.key_switch)
+        self.unset_config(self.key_force)
         self.save()
     
     def install(self, params=None):
@@ -82,7 +117,11 @@ class EolStyleCheck(PluginBase):
         
         Form fields in setup_config() will pass as params.
         """
-        self.set_config()
+        force = params.get('force', 'no')
+        if force != 'no':
+            force = 'yes'
+        self.set_config(self.key_switch, 'yes')
+        self.set_config(self.key_force, force)
         self.save()
         
 def execute(repospath=""):
