@@ -20,5 +20,5 @@ from pysvnmanager.tests import *
 class TestLogsController(TestController):
 
     def test_index(self):
-        response = self.app.get(url_for(controller='logs'))
+        response = self.app.get(url(controller='logs', action='index'))
         # Test response...
