@@ -23,56 +23,59 @@ class TestRoleController(TestController):
 
     def test_index(self):
         # Test redirect to login pange
-        res = self.app.get(url_for(controller='role'))
-        assert res.status == 302
-        self.assertEqual(res.header('location'), 'http://localhost/login')
+        res = self.app.get(url(controller='role', action='index'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/login'), res.location
 
         # Login as common user
         self.login('nobody')
-        res = self.app.get(url_for(controller='role'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='index'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/security/failed'), res.location
         
-        # Permission denied for repos admin(not root admin)
+        # Repos admin(not root admin) can access role controller, but with disabled button.
         self.login('admin2')
-        res = self.app.get(url_for(controller='role'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='index'))
+        assert res.status == "200 OK", res.status
+        assert """
+    <input type="button" name="save_btn"   value='Save'  onClick="do_save(this.form)" DISABLED>
+    <input type="button" name="delete_btn" value='Delete' onClick="do_delete(this.form)" DISABLED>
+    <input type="button" name="cancel_btn" value='Cancel' onClick="role_changed()" DISABLED>""" in res.body, res.body[-300:]
 
         # Login as superuser
         self.login('root')
-        res = self.app.get(url_for(controller='role'))
-        assert res.status == 200
+        res = self.app.get(url(controller='role', action='index'))
+        assert res.status == "200 OK", res.status
         assert """<input type="button" name="save_btn"   value='Save'""" in res.body, res.body
 
     def test_get_role_info(self):
         # authn test
-        res = self.app.get(url_for(controller='role', action='get_role_info'))
-        assert res.status == 302
-        self.assertEqual(res.header('location'), 'http://localhost/login')
+        res = self.app.get(url(controller='role', action='get_role_info'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/login'), res.location
 
         # authz test
         self.login('nobody')
-        res = self.app.get(url_for(controller='role', action='get_role_info'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='get_role_info'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/security/failed'), res.location
         
         # Login as superuser
         self.login('root')
         params = {'role':'',}
-        res = self.app.get(url_for(controller='role', action='get_role_info'), params)
-        assert res.status == 200
+        res = self.app.get(url(controller='role', action='get_role_info'), params)
+        assert res.status == "200 OK", res.status
         assert """id[0]="...";name[0]="Please choose...";
 id[1]="@admin";name[1]="Group:admin";
 id[2]="@all";name[2]="Group:all";
-id[3]="@dev";name[3]="Group:dev";
-id[4]="@test";name[4]="Group:test";
-id[5]="@biz";name[5]="Group:biz";
-id[6]="@group1";name[6]="Group:group1";
-id[7]="@group2";name[7]="Group:group2";
-id[8]="@group3";name[8]="Group:group3";
-id[9]="@office";name[9]="Group:office";
-id[10]="@tech";name[10]="Group:tech";
+id[3]="@biz";name[3]="Group:biz";
+id[4]="@dev";name[4]="Group:dev";
+id[5]="@group1";name[5]="Group:group1";
+id[6]="@group2";name[6]="Group:group2";
+id[7]="@group3";name[7]="Group:group3";
+id[8]="@office";name[8]="Group:office";
+id[9]="@tech";name[9]="Group:tech";
+id[10]="@test";name[10]="Group:test";
 id[11]="&admin";name[11]="Alias:admin";
 id[12]="&pm";name[12]="Alias:pm";
 id[13]="&tm";name[13]="Alias:tm";
@@ -81,8 +84,8 @@ revision="0.2.1";
 """ == res.body, res.body
 
         params = {'role':'@admin',}
-        res = self.app.get(url_for(controller='role', action='get_role_info'), params)
-        assert res.status == 200
+        res = self.app.get(url(controller='role', action='get_role_info'), params)
+        assert res.status == "200 OK", res.status
         assert """id[0]="&admin";name[0]="Alias:admin";
 id[1]="admin1";name[1]="admin1";
 id[2]="admin2";name[2]="admin2";
@@ -92,8 +95,8 @@ revision="0.2.1";
 """ == res.body, res.body
 
         params = {'role':'@group1',}
-        res = self.app.get(url_for(controller='role', action='get_role_info'), params)
-        assert res.status == 200
+        res = self.app.get(url(controller='role', action='get_role_info'), params)
+        assert res.status == "200 OK", res.status
         assert """id[0]="@group2";name[0]="Group:group2";
 id[1]="@group3";name[1]="Group:group3";
 id[2]="user1";name[2]="user1";
@@ -104,8 +107,8 @@ revision="0.2.1";
 """ == res.body, res.body
 
         params = {'role':'@group3',}
-        res = self.app.get(url_for(controller='role', action='get_role_info'), params)
-        assert res.status == 200
+        res = self.app.get(url(controller='role', action='get_role_info'), params)
+        assert res.status == "200 OK", res.status
         assert """id[0]="user3";name[0]="user3";
 id[1]="user31";name[1]="user31";
 id[2]="user32";name[2]="user32";
@@ -114,23 +117,24 @@ revision="0.2.1";
 """ == res.body, res.body
 
         params = {'role':'&admin',}
-        res = self.app.get(url_for(controller='role', action='get_role_info'), params)
-        assert res.status == 200
+        res = self.app.get(url(controller='role', action='get_role_info'), params)
+        assert res.status == "200 OK", res.status
         assert """aliasname = "&admin";username = "jiangxin";
 revision="0.2.1";
 """ == res.body, res.body
 
     def test_save_group(self):
         # authn test
-        res = self.app.get(url_for(controller='role', action='save_group'))
-        assert res.status == 302
-        self.assertEqual(res.header('location'), 'http://localhost/login')
+        res = self.app.get(url(controller='role', action='save_group'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/login'), res.location
 
         # authz test
         self.login('nobody')
-        res = self.app.get(url_for(controller='role', action='save_group'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='save_group'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/security/failed'), res.location
+
 
         # Change group members, autodrop=no
         try:
@@ -140,8 +144,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'rolename':'group3', 'members':'蒋鑫, user3,@group1', 'autodrop':'no', }
-            res = self.app.get(url_for(controller='role', action='save_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_group'), params)
+            assert res.status == "200 OK", res.status
             assert "Recursive group membership for @group1" in res.body, res.body
         
             authz = self.load_authz()
@@ -158,8 +162,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'rolename':'group3', 'members':'蒋鑫, user3,@group1', 'autodrop':'yes', }
-            res = self.app.get(url_for(controller='role', action='save_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_group'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
         
             authz = self.load_authz()
@@ -176,8 +180,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'rolename':'管理员组', 'members':'蒋鑫, user3,@group1' }
-            res = self.app.get(url_for(controller='role', action='save_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_group'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
         
             authz = self.load_authz()
@@ -194,8 +198,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'rolename':'管理员组', 'members':'蒋鑫, user3,@group1', 'revision':'' }
-            res = self.app.get(url_for(controller='role', action='save_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_group'), params)
+            assert res.status == "200 OK", res.status
             assert "Update failed! You are working on a out-of-date revision." in res.body, res.body
         
             authz = self.load_authz()
@@ -206,15 +210,15 @@ revision="0.2.1";
             
     def test_delete_group(self):
         # authn test
-        res = self.app.get(url_for(controller='role', action='delete_group'))
-        assert res.status == 302
-        self.assertEqual(res.header('location'), 'http://localhost/login')
+        res = self.app.get(url(controller='role', action='delete_group'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/login'), res.location
 
         # authz test
         self.login('nobody')
-        res = self.app.get(url_for(controller='role', action='delete_group'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='delete_group'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/security/failed'), res.location
 
         # Delete group failed, ref by other group.
         try:
@@ -224,8 +228,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'role':'group3',}
-            res = self.app.get(url_for(controller='role', action='delete_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='delete_group'), params)
+            assert res.status == "200 OK", res.status
             assert "Group group3 is referenced by group @group1." in res.body, res.body
         finally:
             self.rollback()
@@ -238,8 +242,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'role':'@dev',}
-            res = self.app.get(url_for(controller='role', action='delete_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='delete_group'), params)
+            assert res.status == "200 OK", res.status
             assert "@dev is referenced by [/:/trunk]." in res.body, res.body
         
             authz = self.load_authz()
@@ -256,8 +260,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'role':'all',}
-            res = self.app.get(url_for(controller='role', action='delete_group'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='delete_group'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
         
             authz = self.load_authz()
@@ -268,15 +272,15 @@ revision="0.2.1";
 
     def test_save_alias(self):
         # authn test
-        res = self.app.get(url_for(controller='role', action='save_alias'))
-        assert res.status == 302
-        self.assertEqual(res.header('location'), 'http://localhost/login')
+        res = self.app.get(url(controller='role', action='save_alias'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/login'), res.location
 
         # authz test
         self.login('nobody')
-        res = self.app.get(url_for(controller='role', action='save_alias'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='save_alias'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/security/failed'), res.location
 
         # Change alias successfully
         try:
@@ -286,8 +290,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'aliasname':'admin', 'username':'蒋鑫',}
-            res = self.app.get(url_for(controller='role', action='save_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
         
             authz = self.load_authz()
@@ -299,8 +303,8 @@ revision="0.2.1";
             self.login('蒋鑫')
             #params = {'aliasname':'admin', 'username':'蒋鑫',}
             params = {'aliasname':'admin2', 'username':'jiangxin',}
-            res = self.app.get(url_for(controller='role', action='save_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
             
         finally:
@@ -314,8 +318,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'aliasname':'管理员', 'username':'蒋鑫',}
-            res = self.app.get(url_for(controller='role', action='save_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
         
             authz = self.load_authz()
@@ -332,8 +336,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'aliasname':'admin', 'username':'蒋鑫', 'revision':'123'}
-            res = self.app.get(url_for(controller='role', action='save_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='save_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "Update failed! You are working on a out-of-date revision." in res.body, res.body
         
             authz = self.load_authz()
@@ -345,15 +349,15 @@ revision="0.2.1";
             
     def test_delete_alias(self):
         # authn test
-        res = self.app.get(url_for(controller='role', action='delete_alias'))
-        assert res.status == 302
-        self.assertEqual(res.header('location'), 'http://localhost/login')
+        res = self.app.get(url(controller='role', action='delete_alias'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/login'), res.location
 
         # authz test
         self.login('nobody')
-        res = self.app.get(url_for(controller='role', action='delete_alias'))
-        assert res.status == 302, res.status
-        assert res.header('location')=='http://localhost/security/failed', res.header('location')
+        res = self.app.get(url(controller='role', action='delete_alias'))
+        assert res.status == "302 Found", res.status
+        assert res.location.endswith('/security/failed'), res.location
 
         # Delete alias successfully
         try:
@@ -363,8 +367,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'aliasname':'tm'}
-            res = self.app.get(url_for(controller='role', action='delete_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='delete_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "" == res.body, res.body
         
             authz = self.load_authz()
@@ -381,8 +385,8 @@ revision="0.2.1";
 
             self.login('root')
             params = {'aliasname':'tm', 'revision':''}
-            res = self.app.get(url_for(controller='role', action='delete_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='delete_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "Update failed! You are working on a out-of-date revision." in res.body, res.body
         
             authz = self.load_authz()
@@ -400,12 +404,12 @@ revision="0.2.1";
 
             self.login('root')
             params = {'aliasname':'pm', 'revision':''}
-            res = self.app.get(url_for(controller='role', action='delete_alias'), params)
-            assert res.status == 200
+            res = self.app.get(url(controller='role', action='delete_alias'), params)
+            assert res.status == "200 OK", res.status
             assert "&pm is referenced by [/:/trunk]." in res.body, res.body
         
             authz = self.load_authz()
             userobj = authz.get_userobj('&pm')
             self.assert_(unicode(userobj) == u'pm = dev1', unicode(userobj).encode('utf-8'))
         finally:
-            self.rollback()
\ No newline at end of file
+            self.rollback()
