@@ -19,8 +19,11 @@
 """Setup the pySvnManager application"""
 import logging
 
+import pylons.test
+
+from pysvnmanager.config.environment import load_environment
+
 from paste.deploy import appconfig
-from pylons import config
 from shutil import copyfile
 import os
 from pkg_resources import resource_filename
@@ -31,9 +34,16 @@ log = logging.getLogger(__name__)
 
 def setup_app(command, conf, vars):
     """Place any commands to setup pysvnmanager here"""
-    load_environment(conf.global_conf, conf.local_conf)
+    # Don't reload the app if it was loaded under the testing environment
+    if not pylons.test.pylonsapp:
+        load_environment(conf.global_conf, conf.local_conf)
+    else:
+        # Hack pylons: config['here'] is used in many places, so setup here.
+        from pylons import config
+        wsgiapp = pylons.test.pylonsapp
+        config['here'] = wsgiapp.config.get('here')
 
-    here = config['here']
+    here = conf['here']
 
     if not os.path.exists(here+'/config'):
         os.mkdir(here+'/config')
@@ -49,4 +59,3 @@ def setup_app(command, conf, vars):
             log.warning("Warning: %s already exist, ignored." % f)
         else:
             copyfile(src, dest)
-
